# Authenticator directories, please modify, if paths are not valid
$AuthenticatorPath = "C:\Serviceware\Common\Authenticator\"
$AuthenticatorConfigPath = "C:\Serviceware\Common\Authenticator-configuration\"
$BackupDirectory = "C:\Serviceware\Common\Authenticator-Backup\"

Write-Host "Uninstaller for Serviceware Authenticator 1.0"
Write-Host "The script will stop all running Java processes. Do you want to continue? [y/n]"
$result = ""
while($result -ne "y" -and $result -ne "n")
{
    $result = Read-Host
}
if($result -eq "n")
{
    exit 
}

# Stop Serviceware Authenticator service
Write-Host "Serviceware Authenticator service will be stopped"
Stop-Service -DisplayName "Serviceware Authenticator" -NoWait
$AuthenticatorService = Get-Service -DisplayName "Serviceware Authenticator"
$Count = 0
while (($AuthenticatorService.Status -ne 1) -and ($Count -lt 10)) # Whait while service is not stopped
{
    Start-Sleep -Milliseconds 2000
    Write-Host "."
    $Count++
}
if (($AuthenticatorService.Status -ne 1) -and ($Count -ge 10))
{
    Stop-Process -Name "wildfly-service" -Force
}

# Backup Authenticator configuration
Write-Host "Backup current Authenticator configuration to " + $BackupDirectory
New-Item -Path $BackupDirectory -ItemType Directory -Force
Copy-Item "${AuthenticatorPath}standalone\configuration\standalone.xml" -Destination $BackupDirectory
Copy-Item "${AuthenticatorPath}standalone\configuration\application.keystore" -Destination $BackupDirectory -ErrorAction SilentlyContinue
Copy-Item "${AuthenticatorPath}bin\standalone.conf.bat" -Destination $BackupDirectory
Copy-Item "${AuthenticatorConfigPath}terraform.tfstate" -Destination $BackupDirectory

# Uninstall Serviceware Authenticator 1.0
Write-Host "Uninstall Serviceware Authenticator 1.0"
$Authenticator = Get-WmiObject -Class Win32_Product | Where-Object{$_.Name -eq "Serviceware Authenticator"}
$Authenticator.Uninstall()

# Cleanup old installation
Write-Host "Cleanup Serviceware Authenticator 1.0 directory"
$JavaProcesses = Get-Process -Name "java"
foreach ($JavaProcess in $JavaProcesses)
{
    Stop-Process $JavaProcess -Force
}
Remove-Item $AuthenticatorPath -Recurse -Force
Remove-Item $AuthenticatorConfigPath -Recurse -Force
